---
--- Generated by sdk
--- DateTime: 2020-08-18
---

--热更新模块
local _class = {
    _name = "Hotfix",
    _version = "1.0.3",
    _httpHost = 'http://hf.youzu.com/',
    _file_config_path = 'file://yz_lua_sdk/Module/config.json',
    _file_config_array = Array()
}

---@public
function _class:new(game_id, device_id)
    local o = {}
    setmetatable(o, { __index = self })
    self.game_id = game_id
    self.device_id = device_id
    return o
end

--加载本地config文件
function _class:loadConfig()
    if self.game_id or self.device_id then
        File:asyncReadFile(self._file_config_path,function (codeNumber, file)
            if codeNumber == 0 then
                self._file_config_array = StringUtil:jsonToArray(file)
                self:checkVersion()
            end
        end)
    else
        print('缺少game_id or device_id,hotfix->return')
    end
    
end

--网络请求，检查版本更新
function _class:checkVersion()
    print('开始网络请求，检查版本')
    local http = Http()
    local params = {}
    params['game_id'] = self.game_id
    params['device_id'] = self.device_id

    local os = ''
    if System:iOS() then
        os = 'ios'
    else
        os = 'android'
    end
    params['os'] = os
    http:get(self._httpHost..'/hf',params,Map(),function (success, resp, error)
        if success and resp then
            if(resp:get('code') == 0) then
                local array = resp:get('data')
                if array then
                    for i = 1, array:size() do
                        local module_id = array:get(i):get("module_id")
                        for j = 1, self._file_config_array:size() do
                            --判断网络版本和本地版本是否一致
                            local file_module_id = self._file_config_array:get(j):get('module_id')
                            if module_id == file_module_id then
                                local version = array:get(i):get('version')
                                local file_module_version = self._file_config_array:get(j):get('version')
                                if version ~= file_module_version then
                                    --不一致则需要判断本地是否已经有对应版本
                                    local download_url = array:get(i):get('download_url')
                                    local path = 'file://yz_lua_sdk/Module/'..module_id..'/'..version
                                    local exist = File:exist(path)
                                    if exist then
                                        -- 本地存在,写入新版本
                                        self:write(module_id,version)
                                    else
                                        -- 不存在,下载新版本
                                        self:download(download_url,module_id,version)
                                    end
                                else
                                    print('模块：'..module_id..'已经是最新版本')
                                end
                            end
                        end
                    end
                else
                    print('hotifix api data格式异常')
                end
            else
                print('hotifix api code异常')
            end
        else
          print('hotfix api http error')
        end
    end)
end


--下载plugin,下载成功成功后校验MD5
function _class:download(_download_url,module_id,new_version)
    local _download_path = 'file://yz_lua_sdk/Module/'..module_id .. '/' ..new_version ..'.zip'
    local _unzip_Pah = 'file://yz_lua_sdk/Module/'..module_id..'/'..new_version
    -- body
    local http = Http()
    local params = {}
    params['__path'] = _download_path
    http:download(_download_url,params,Map(),
                function(progress,total)
                end,
                function(success, response, error)
                    if success then
                        --获取下载文件的md5
                        File:asyncMd5File(_download_path,function (md5)
                            --校验md5，确认文件完整性
                            -- if _md5 == md5 then
                            --     self:unzip(_download_path,_unzip_Pah,module_id,new_version)
                            -- end
                            self:unzip(_download_path,_unzip_Pah,module_id,new_version)
                        end)
                    end
                end)
end

function _class:unzip(zip_path,unzip_path,module_id,new_version)
    File:asyncUnzipFile(zip_path,unzip_path,function(code,sourcePath)
        -- body
        --code  解压结果，0 成功，其他失败
        if code == 0 then
            --解压成功
            --写入本地config文件
            self:write(module_id,new_version)
            --删除zip文件
            self:delete(zip_path)
        end
    end)
    
end

function _class:write(module_id,new_version)
    for i = 1, self._file_config_array:size() do
        if module_id == self._file_config_array:get(i):get('module_id') then
            print('config.json写入新版本')
            self._file_config_array:get(i):put("version", new_version)
        end
    end

    local writeContent = self._file_config_array
    if System:iOS() then
        writeContent = StringUtil:arrayToJSON(self._file_config_array)
    end
    -- 写入文件
    File:asyncWriteArray(
        self._file_config_path,
        writeContent,
        function (code,sourcePath)
            if code == 0 then
                print('hotfix complete')
            end
        end)
end

function _class:delete(path)
    File:asyncDelete(path,function (code,dirPath)
        print('文件删除成功')
    end)
end



local game_id = window:getExtra():get('game_id')
local device_id = window:getExtra():get('device_id')
_class:new(game_id,device_id)
_class:loadConfig()
return _class