local _class = {
    _name = 'TabToolBar',
    _version = '1.0'
}

---@public
function _class:new()
    local o = {}
    setmetatable(o, { __index = self })
    return o
end

---@public
function _class:setupItems(normalImages, selectImages,normalBackImages,selectBackImages, titles,normalTitleColor,selectTitleColor,callback)
    self.clickCallback = callback
    self:createBarButtonItems(normalImages, selectImages,normalBackImages,selectBackImages,titles,normalTitleColor,selectTitleColor)
end

---@private
function _class:createBarButtonItems(normalImages, selectImages,normalBackImages,selectBackImages,titles,normalTitleColor,selectTitleColor)
    if normalImages:size() ~= selectImages:size() then
        return
    end
    self.normalImages = normalImages
    self.selectImages = selectImages
    self.normalBackImages = normalBackImages
    self.selectBackImages = selectBackImages
    self.normalTitleColor = normalTitleColor
    self.selectTitleColor = selectTitleColor
    local itemCount = titles:size()

    local tabToolBarWidth = 50

    local barItemWidth = 26

    local viewHeight = System:screenSize():height() - 40

    local itemHeight = viewHeight / 4

    print('itemHeight:'..itemHeight)

    self.contentView = View()
            :width(tabToolBarWidth):height(viewHeight):priority(1)
            :bgImage(_ImageRootRoute .. "images/img_tabbar_back.png")
            :marginLeft(20)

    self.tabToolBar = LinearLayout(LinearType.VERTICAL)
    self.tabToolBar:width(tabToolBarWidth):height(MeasurementType.MATCH_PARENT)

    for i = 1, itemCount do
        local itemView = LinearLayout(LinearType.VERTICAL)
                                    :width(tabToolBarWidth)
                                    :height(MeasurementType.WRAP_CONTENT)
                                    :weight(1)
                                    
        local barItem = ImageView():width(barItemWidth)
                                   :height(barItemWidth)
                                   :marginTop(20)
                                   :setGravity(Gravity.CENTER)

        local titleLabel = Label():width(MeasurementType.WRAP_CONTENT)
                                  :height(MeasurementType.WRAP_CONTENT)
                                  :marginTop(4)
                                  :setGravity(Gravity.CENTER)

        local lineView = View():width(tabToolBarWidth)
                                   :height(0.5)
                                   :marginTop(itemHeight - 20 - barItemWidth - 16 - 4)
                                   :bgImage(_ImageRootRoute .. "images/img_tabbar_line.png")
      
        -- image
        itemView:onClick(function()
            self:updateBarItemImages(barItem,itemView,titleLabel,i)
            self.clickCallback(i)
        end)
        if i == 1 then
            self.preBarItem = barItem
            self.preIndex = 1
            self.preBarBack = itemView
            self.preTitle = titleLabel
            barItem:image(selectImages:get(1))
            itemView:bgImage(selectBackImages:get(1))
            titleLabel:textColor(selectTitleColor)
        else
            barItem:image(normalImages:get(i))
            itemView:bgImage(normalBackImages:get(i))
            titleLabel:textColor(normalTitleColor)
        end

        titleLabel:text(titles:get(i))

        itemView:addView(barItem):addView(titleLabel):addView(lineView)
       
        self.tabToolBar:addView(itemView)
    end

    self.contentView:addView(self.tabToolBar)

end

function _class:updateBarItemImages(barItem, barback, titleLabel, index)
    if index == self.preIndex then
        return --点击同一个barItem不更新image
    end
    self.preBarItem:image(self.normalImages:get(self.preIndex))
    barItem:image(self.selectImages:get(index))
   
    self.preBarBack:bgImage(self.normalBackImages:get(self.preIndex))
    barback:bgImage(self.selectBackImages:get(index))

    self.preTitle:textColor(self.normalTitleColor)
    titleLabel:textColor(self.selectTitleColor)

    self.preBarBack = barback
    self.preBarItem = barItem
    self.preTitle = titleLabel
    self.preIndex = index
end

return _class